@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -80,5 +80,12 @@ class EmployeeView(CoreOfficeMasterView):
             office_url, employee.number)
 
 
-def includeme(config):
+def defaults(config, **kwargs):
+    base = globals()
+
+    EmployeeView = kwargs.get('EmployeeView', base['EmployeeView'])
     EmployeeView.defaults(config)
+
+
+def includeme(config):
+    defaults(config)
