@@ -92,11 +92,4 @@ class VendorView(base.VendorView):
 
 
 def includeme(config):
-
-    # TODO: ugh
-    # autocomplete
-    config.add_route('vendors.autocomplete', '/vendors/autocomplete')
-    config.add_view(base.VendorsAutocomplete, route_name='vendors.autocomplete',
-                    renderer='json', permission='vendors.list')
-
     VendorView.defaults(config)
